@@ -103,6 +103,7 @@ class DatasetAssembler(EoFields):
         "landsat:collection_number",
         "landsat:landsat_product_id",
         "landsat:landsat_scene_id",
+        "landsat:scene_id",
         "landsat:wrs_path",
         "landsat:wrs_row",
         "mission",
@@ -219,6 +220,10 @@ class DatasetAssembler(EoFields):
             self.names = ComplicatedNamingConventionsDerivatives.for_c3_derivatives(
                 self
             )
+        elif naming_conventions == "deafrica":
+            self.names = (
+                ComplicatedNamingConventionsDerivatives.for_deafrica_derivatives(self)
+            )
         else:
             raise NotImplementedError("configurable naming conventions")
 
